
#include <inttypes.h>
#include <stdio.h>
#include <URL.h>                                                                                                                                                                
#include <ResultSet.h>
#include <PreparedStatement.h>
#include <Connection.h>
#include <ConnectionPool.h>
#include <SQLException.h>

int main (void) 
{
	Connection_T c;
	PreparedStatement_T stmt;
	URL_T uri;
	ConnectionPool_T pool;
	ResultSet_T r;
	uint64_t message_id = 1010;
       
	uri = URL_new("mysql://localhost/test?user=test&password=test&encoding=utf8");
       	pool = ConnectionPool_new(uri);
	ConnectionPool_start(pool);

	c = ConnectionPool_getConnection(pool);
	TRY
		int part_key = 0, prev_key = 0;
		int part_depth, part_order, is_header;
		const char *date;
		
		Connection_clear(c);
		stmt = Connection_prepareStatement(c, 
				"SELECT l.part_key,l.part_depth,l.part_order,l.is_header,DATE_FORMAT(ph.internal_date, GET_FORMAT(DATETIME,'ISO')),p.data "
				"from dbmail_mimeparts p "
				"join dbmail_partlists l on p.id=l.part_id "
				"join dbmail_physmessage ph on ph.id=l.physmessage_id "
				"where l.physmessage_id = ? order by l.part_key, l.part_order asc");
		PreparedStatement_setLLong(stmt, 1, (long long)message_id);
		r = PreparedStatement_executeQuery(stmt);
		while (ResultSet_next(r)) {
			if (part_key)
				prev_key = part_key;
			part_key = ResultSet_getInt(r, 1);
			part_depth = ResultSet_getInt(r, 2);
			part_order = ResultSet_getInt(r, 3);
			is_header = ResultSet_getInt(r, 4);
			date = ResultSet_getString(r, 5);
			printf("%5d ", part_key);
			if (part_key < prev_key) {
				printf("Error: primary ordering broken\n");
				break;
			}
			/*
			printf("%5d ", part_depth);
			printf("%5d ", part_order);
			printf("%5d ", is_header);
			printf("%s ", date);
			*/
			printf("\n");
		}
	CATCH(SQLException) 
		printf("SQLException: %s", Exception_frame.message);
	FINALLY
		Connection_close(c);
	END_TRY;


	return 0;


}
